@@ -14,13 +14,12 @@ Link: https://github.com/blei-lab/onlineldavb
 from joblib import Parallel, delayed, effective_n_jobs
 import numpy as np
 import scipy.sparse as sp
-from scipy.special import gammaln
+from scipy.special import gammaln, logsumexp
 import warnings
 
 from sklearn.base import BaseEstimator, TransformerMixin
 from sklearn.utils import (check_random_state, check_array,
                            gen_batches, gen_even_slices)
-from sklearn.utils.fixes import logsumexp
 from sklearn.utils.validation import check_non_negative
 from sklearn.exceptions import NotFittedError
 
